==> drupalmoduleupgrader-8.x-0.7.tar.gz: drupalmoduleupgrader/tests/src/Unit/Plugin/DMU/Converter/Functions/CacheSetTest.php <==
<?php

namespace Drupal\Tests\drupalmoduleupgrader\Unit\Plugin\DMU\Converter\Functions;

use Drupal\drupalmoduleupgrader\Plugin\DMU\Converter\Functions\CacheSet;
use Pharborist\Parser;

/**
 * @group DMU.Converter.Functions
 * @covers \Drupal\drupalmoduleupgrader\Plugin\DMU\Converter\Functions\CacheSet
 */
class CacheSetTest extends FunctionCallModifierTest {

  public function setUp() {
    parent::setUp();
    $this->plugin = new CacheSet([], 'cache_set', []);
  }

  public function testRewriteDefaultBin() {
    $function_call = Parser::parseExpression('cache_set("foo", array())');
    $rewritten = $this->plugin->rewrite($function_call, $this->target);
    $this->assertInstanceOf('\Pharborist\Objects\ObjectMethodCallNode', $rewritten);
    $this->assertEquals('\Drupal::cache()->set("foo", array())', $rewritten->getText());
  }

  public function testRewriteSpecificBinNoExpiration() {
    $function_call = Parser::parseExpression('cache_set("foo", array(), "baz")');
    $rewritten = $this->plugin->rewrite($function_call, $this->target);
    $this->assertInstanceOf('\Pharborist\Objects\ObjectMethodCallNode', $rewritten);
    $this->assertEquals('\Drupal::cache("baz")->set("foo", array())', $rewritten->getText());
  }

  public function testRewriteSpecificBinWithExpiration() {
    $function_call = Parser::parseExpression('cache_set("foo", array(), "bar", 67890)');
    $rewritten = $this->plugin->rewrite($function_call, $this->target);
    $this->assertInstanceOf('\Pharborist\Objects\ObjectMethodCallNode', $rewritten);
    $this->assertEquals('\Drupal::cache("bar")->set("foo", array(), 67890)', $rewritten->getText());
  }

}

==> drupalmoduleupgrader-8.x-1.0.tar.gz: drupalmoduleupgrader/tests/src/Unit/Plugin/DMU/Converter/Functions/CacheSetTest.php <==
<?php

namespace Drupal\Tests\drupalmoduleupgrader\Unit\Plugin\DMU\Converter\Functions;

use Drupal\drupalmoduleupgrader\Plugin\DMU\Converter\Functions\CacheSet;
use Pharborist\Parser;

/**
 * @group DMU.Converter.Functions
 * @covers \Drupal\drupalmoduleupgrader\Plugin\DMU\Converter\Functions\CacheSet
 */
class CacheSetTest extends FunctionCallModifierTest {

  public function setUp() {
    parent::setUp();
    $this->plugin = CacheSet::create($this->container, [], 'cache_set', []);
  }

  public function testRewriteDefaultBin() {
    $function_call = Parser::parseExpression('cache_set("foo", array())');
    $rewritten = $this->plugin->rewrite($function_call, $this->target);
    $this->assertInstanceOf('\Pharborist\Objects\ObjectMethodCallNode', $rewritten);
    $this->assertEquals('\Drupal::cache()->set("foo", array())', $rewritten->getText());
  }

  public function testRewriteSpecificBinNoExpiration() {
    $function_call = Parser::parseExpression('cache_set("foo", array(), "baz")');
    $rewritten = $this->plugin->rewrite($function_call, $this->target);
    $this->assertInstanceOf('\Pharborist\Objects\ObjectMethodCallNode', $rewritten);
    $this->assertEquals('\Drupal::cache("baz")->set("foo", array())', $rewritten->getText());
  }

  public function testRewriteSpecificBinWithExpiration() {
    $function_call = Parser::parseExpression('cache_set("foo", array(), "bar", 67890)');
    $rewritten = $this->plugin->rewrite($function_call, $this->target);
    $this->assertInstanceOf('\Pharborist\Objects\ObjectMethodCallNode', $rewritten);
    $this->assertEquals('\Drupal::cache("bar")->set("foo", array(), 67890)', $rewritten->getText());
  }

}
